/**
 * Copyright (C) 2009-2013 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.http;

import java.io.UnsupportedEncodingException;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 *
 * @author ingenthr
 */
public class HttpUtilTest {

  /**
   * Test the generation of authorisation header given
   * a username and password from HttpUtil class.
   *
   * @pre Provide any user and password for authorisation.
   *
   * @throws UnsupportedEncodingException
   */
  @Test
  public void testBuildAuthHeader() throws UnsupportedEncodingException {
    HttpUtil.buildAuthHeader("foo", "bar");
  }

  /**
   * Test the generation of authorisation header given a
   * username and password from HttpUtil class.
   *
   * @pre Provide any user and password for authorisation.
   * @post Asserts if the result matches the given string.
   *
   * @throws UnsupportedEncodingException
   */
  @Test
  public void testBuildAuthHeaderUTF8() throws UnsupportedEncodingException {
    String result = HttpUtil.buildAuthHeader("blahblah",
            "bla@@h");
    // string inspired by https://github.com/trondn/libcouchbase/issues/3
    assertEquals("Basic YmxhaGJsYWg6YmxhQEBo", result);
  }
}
